seedir.errors API documentation
Description: Custom exceptions for seedir.

# Module `seedir.errors`

Custom exceptions for seedir.

Expand source code

    # -*- coding: utf-8 -*-
    """
    Custom exceptions for seedir.

    """

    # NOTE: SeedirError removed for 0.4.0

    # class SeedirError(Exception):
    #     """Class for representing errors from module `seedir.realdir`"""

    class FakedirError(Exception):
        """Class for handling errors from module `seedir.fakedir`"""

## Classes

`class FakedirError (*args, **kwargs)`

  Class for handling errors from module `seedir.fakedir`

  Expand source code

      class FakedirError(Exception):
          """Class for handling errors from module `seedir.fakedir`"""

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException